# Документация API Чаты

Модуль `PlayerokChatsApi` предоставляет функционал для работы с чатами на платформе Playerok. Он позволяет отправлять сообщения, получать статусы сообщений, отслеживать новые и непрочитанные сообщения, а также управлять информацией о чатах.

## Инициализация

```python
from playerok-requests-api.chats import PlayerokChatsApi

api = PlayerokChatsApi(cookies_file="cookies.json", logger=False)
```

- **cookies_file**: Путь к файлу с cookies для аутентификации (по умолчанию `cookies.json`).
- **logger**: Включение/выключение логирования (по умолчанию `False`).

## Методы

| Метод                            | Описание                                                                 | Возвращаемое значение                     |
|----------------------------------|--------------------------------------------------------------------------|------------------------------------------|
| `get_username()`                 | Получает имя пользователя и ID текущего аккаунта из cookies.             | Кортеж `(username, id)` или `('', '')` при ошибке. |
| `on_username_id_get(profileusername, username)` | Получает ID чата для указанных пользователей.                     | `str` (ID чата) или `None` при ошибке.   |
| `on_send_message(username, text)`| Отправляет сообщение указанному пользователю.                           | Словарь с ответом API или `None` при ошибке. |
| `get_status_messages(difference=300)` | Получает сообщения со статусами сделок за указанный период (в секундах). | Список словарей с данными `{id, status, timestamp}` или `None`. |
| `get_new_messages(interval=5, max_interval=30)` | Получает новые сообщения с периодической проверкой.             | Список словарей с данными `{chat_id, participant, message, date}`. |
| `get_messages_info(unread=False)`| Получает информацию о всех чатах (или только с непрочитанными сообщениями). | Список словарей с данными чатов или `[]`. |
| `fetch_chats(after_cursor=None)` | Получает чаты с пагинацией.                                             | Словарь с данными чатов или `None` при ошибке. |
| `get_unread_messages()`          | Возвращает количество непрочитанных сообщений.                          | `int` (количество сообщений).            |

## Пример использования

### Отправка сообщения

```python
username = "example_user"
message = "Привет, как дела?"
response = api.on_send_message(username, message)
if response:
    print("Сообщение отправлено:", response)
else:
    print("Ошибка при отправке сообщения")
```

### Получение новых сообщений

```python
new_messages = api.get_new_messages()
if new_messages:
    for msg in new_messages:
        print(f"От: {msg['participant']}, Сообщение: {msg['message']}, Время: {msg['date']}")
else:
    print("Новых сообщений нет")
```

### Подсчет непрочитанных сообщений

```python
unread_count = api.get_unread_messages()
print(f"Непрочитанных сообщений: {unread_count}")
```

## Обработка ошибок

- При ошибках (например, неверный username, проблемы с API или отсутствие чата) методы возвращают `None`, пустой список или 0 и выводят сообщение об ошибке.
- Включите логирование (`logger=True`) для получения дополнительной информации об ошибках.

## Примечания

- Метод `get_status_messages` требует доработки для обработки всех страниц сообщений, а не только первой.
- Метод `get_new_messages` работает в цикле с настраиваемыми интервалами проверки, что может быть полезно для мониторинга чатов в реальном времени.