# Документация API Сделки

Модуль `PlayerokDealsApi` предоставляет функционал для работы со сделками на платформе Playerok. Он позволяет подтверждать сделки и получать список оплаченных сделок.

## Инициализация

```python
from playerok_requests_api.deals import PlayerokDealsApi

api = PlayerokDealsApi(cookies_file="cookies.json", logger=False)
```

- **cookies_file**: Путь к файлу с cookies для аутентификации (по умолчанию `cookies.json`).
- **logger**: Включение/выключение логирования (по умолчанию `False`).

## Методы

| Метод                     | Описание                                                                 | Возвращаемое значение                     |
|---------------------------|--------------------------------------------------------------------------|------------------------------------------|
| `get_username()`          | Получает имя пользователя и ID текущего аккаунта из cookies.             | Кортеж `(username, id)` или `('', '')` при ошибке. |
| `deal_confirm(id)`        | Подтверждает сделку по её ID.                                            | Словарь с ответом API или `None` при ошибке. |
| `get_actual_deals()`      | Получает список актуальных оплаченных сделок для текущего пользователя.  | Словарь с данными сделок или `None` при ошибке. |

## Пример использования

### Подтверждение сделки

```python
deal_id = "12345"
response = api.deal_confirm(deal_id)
if response:
    print("Сделка успешно подтверждена:", response)
else:
    print("Ошибка при подтверждении сделки")
```

### Получение актуальных сделок

```python
deals = api.get_actual_deals()
if deals:
    print("Актуальные сделки:", deals)
else:
    print("Ошибка при получении сделок")
```

## Обработка ошибок

- При ошибках (например, неверный ID сделки или проблемы с API) методы возвращают `None` и выводят сообщение об ошибке.
- Включите логирование (`logger=True`) для диагностики проблем.